@@ -3,9 +3,9 @@ from __future__ import annotations
 
 from abc import ABC
 import asyncio
-from collections.abc import Mapping, MutableMapping, MutableSequence, Sequence
+from collections.abc import MutableMapping, Sequence
 import time
-from typing import Type
+from typing import Dict, List, Type
 
 from pyplumio.const import (
     BROADCAST_ADDRESS,
@@ -49,7 +49,7 @@ from pyplumio.helpers.typing import (
 )
 from pyplumio.structures.boiler_parameters import PARAMETER_BOILER_CONTROL
 
-devices: Mapping[int, str] = {
+devices: Dict[int, str] = {
     ECOMAX_ADDRESS: "EcoMAX",
     ECOSTER_ADDRESS: "EcoSTER",
 }
@@ -69,7 +69,7 @@ def get_device_handler(address: int) -> str:
 class FrameVersions:
     """Represents frame versions storage."""
 
-    versions: MutableMapping[int, int]
+    versions: Dict[int, int]
     _queue: asyncio.Queue
     _device: Device
 
@@ -102,7 +102,7 @@ class FrameVersions:
 class AsyncDevice(ABC, TaskManager):
     """Represents a device with awaitable properties."""
 
-    _callbacks: MutableMapping[str, MutableSequence[ValueCallback]]
+    _callbacks: Dict[str, List[ValueCallback]]
 
     def __init__(self):
         """Initializes Async Device object."""
@@ -114,8 +114,8 @@ class AsyncDevice(ABC, TaskManager):
         """Return a value. When encountering a parameter, only it's
         value will be returned. To return the Parameter object use
         get_parameter(name: str) method."""
-        while not hasattr(self, name):
-            await asyncio.sleep(0)
+        if not hasattr(self, name):
+            await self.create_event(name).wait()
 
         value = getattr(self, name)
         return int(value) if isinstance(value, Parameter) else value
@@ -124,8 +124,8 @@ class AsyncDevice(ABC, TaskManager):
     async def set_value(self, name: str, value: Numeric) -> None:
         """Set parameter value. Name should point
         to a valid parameter object."""
-        while not hasattr(self, name):
-            await asyncio.sleep(0)
+        if not hasattr(self, name):
+            await self.create_event(name).wait()
 
         parameter = getattr(self, name)
         if isinstance(parameter, Parameter):
@@ -137,8 +137,8 @@ class AsyncDevice(ABC, TaskManager):
     @timeout(VALUE_TIMEOUT)
     async def get_parameter(self, name: str) -> Parameter:
         """Return a parameter."""
-        while not hasattr(self, name):
-            await asyncio.sleep(0)
+        if not hasattr(self, name):
+            await self.create_event(name).wait()
 
         parameter = getattr(self, name)
         if isinstance(parameter, Parameter):
@@ -158,25 +158,24 @@ class AsyncDevice(ABC, TaskManager):
                 value = return_value if return_value is not None else value
 
         setattr(self, name, value)
+        self.set_event(name)
 
     async def shutdown(self) -> None:
         """Cancel scheduled tasks."""
         self.cancel_tasks()
         await self.wait_for_tasks()
 
-    def register_callback(self, sensors: Sequence[str], callback: ValueCallback):
-        """Register callback for sensor change."""
-        for sensor in sensors:
-            if sensor not in self._callbacks:
-                self._callbacks[sensor] = []
+    def register_callback(self, name: str, callback: ValueCallback) -> None:
+        """Register callback for a value change."""
+        if name not in self._callbacks:
+            self._callbacks[name] = []
 
-            self._callbacks[sensor].append(callback)
+        self._callbacks[name].append(callback)
 
-    def remove_callback(self, sensors: Sequence[str], callback: ValueCallback):
-        """Remove callback for sensor change."""
-        for sensor in sensors:
-            if sensor in self._callbacks and callback in self._callbacks[sensor]:
-                self._callbacks[sensor].remove(callback)
+    def remove_callback(self, name: str, callback: ValueCallback) -> None:
+        """Remove value change callback."""
+        if name in self._callbacks and callback in self._callbacks[name]:
+            self._callbacks[name].remove(callback)
 
 
 class Mixer(AsyncDevice):
@@ -193,7 +192,7 @@ class Device(AsyncDevice):
 
     address: int = BROADCAST_ADDRESS
     _queue: asyncio.Queue
-    _required_frames: Sequence[Type[Request]] = []
+    _required_frames: List[Type[Request]] = []
 
     def __init__(self, queue: asyncio.Queue):
         """Initialize new Device object."""
@@ -201,7 +200,7 @@ class Device(AsyncDevice):
         self._queue = queue
         versions = FrameVersions(queue, device=self)
         versions.update({x.frame_type: 0 for x in self.required_frames})
-        self.register_callback([DATA_FRAME_VERSIONS], on_change(versions.async_update))
+        self.register_callback(DATA_FRAME_VERSIONS, on_change(versions.async_update))
 
     def handle_frame(self, frame: Frame) -> None:
         """Handle received frame."""
@@ -210,7 +209,7 @@ class Device(AsyncDevice):
                 self.set_attribute(name, value)
 
     @property
-    def required_frames(self) -> Sequence[Type[Request]]:
+    def required_frames(self) -> List[Type[Request]]:
         """Return list of required frames."""
         return self._required_frames
 
@@ -224,9 +223,9 @@ class EcoMAX(Device):
     """Represents ecoMAX controller."""
 
     address: int = ECOMAX_ADDRESS
-    mixers: MutableMapping[int, Mixer] = {}
+    mixers: Dict[int, Mixer] = {}
     _fuel_burned_timestamp: float = 0.0
-    _required_frames: Sequence[Type[Request]] = [
+    _required_frames: List[Type[Request]] = [
         requests.UID,
         requests.DataSchema,
         requests.BoilerParameters,
@@ -237,17 +236,15 @@ class EcoMAX(Device):
     def __init__(self, queue: asyncio.Queue):
         """Initialize new ecoMAX object."""
         super().__init__(queue)
-        self._mixers: MutableMapping[int, Mixer] = {}
+        self._mixers: Dict[int, Mixer] = {}
         self._fuel_burned_timestamp = time.time()
-        self.register_callback([DATA_BOILER_SENSORS], self._add_boiler_sensors)
-        self.register_callback(
-            [DATA_MODE], on_change(self._add_boiler_control_parameter)
-        )
-        self.register_callback([DATA_FUEL_CONSUMPTION], self._add_burned_fuel_counter)
-        self.register_callback([DATA_BOILER_PARAMETERS], self._add_boiler_parameters)
-        self.register_callback([DATA_REGDATA], self._parse_regulator_data)
-        self.register_callback([DATA_MIXER_SENSORS], self._set_mixer_sensors)
-        self.register_callback([DATA_MIXER_PARAMETERS], self._set_mixer_parameters)
+        self.register_callback(DATA_BOILER_SENSORS, self._add_boiler_sensors)
+        self.register_callback(DATA_MODE, on_change(self._add_boiler_control_parameter))
+        self.register_callback(DATA_FUEL_CONSUMPTION, self._add_burned_fuel_counter)
+        self.register_callback(DATA_BOILER_PARAMETERS, self._add_boiler_parameters)
+        self.register_callback(DATA_REGDATA, self._parse_regulator_data)
+        self.register_callback(DATA_MIXER_SENSORS, self._set_mixer_sensors)
+        self.register_callback(DATA_MIXER_PARAMETERS, self._set_mixer_parameters)
 
     def _get_mixer(self, mixer_number: int) -> Mixer:
         """Get or create a new mixer object and add it to the device."""
@@ -266,9 +263,9 @@ class EcoMAX(Device):
 
     async def _add_boiler_parameters(
         self, parameters: Parameters
-    ) -> MutableMapping[str, Parameter]:
+    ) -> Dict[str, Parameter]:
         """Add Parameter objects to the device object."""
-        parameter_objects: MutableMapping[str, Parameter] = {}
+        parameter_objects: Dict[str, Parameter] = {}
         for name, value in parameters.items():
             cls = (
                 BoilerBinaryParameter if is_binary_parameter(value) else BoilerParameter
