@@ -1,9 +1,8 @@
 """Contains response frames."""
 from __future__ import annotations
 
-from collections.abc import Mapping, MutableSequence
 import struct
-from typing import Tuple
+from typing import Dict, List, Tuple
 
 from pyplumio import util
 from pyplumio.const import (
@@ -66,7 +65,7 @@ class ProgramVersion(Response):
             version_info.struct_version,
             version_info.device_id,
             version_info.processor_signature,
-            *(int(x) for x in version_info.software.split(".", 2)),
+            *map(int, version_info.software.split(".", 2)),
             self.sender,
         )
 
@@ -80,10 +79,14 @@ class ProgramVersion(Response):
             version_info.struct_version,
             version_info.device_id,
             version_info.processor_signature,
-            software_version,
+            software_version1,
+            software_version2,
+            software_version3,
             self.recipient,
-        ] = struct.unpack_from("<2sB2s3s3sB", message)
-        version_info.software = ".".join(str(x) for x in software_version)
+        ] = struct.unpack_from("<2sB2s3s3HB", message)
+        version_info.software = ".".join(
+            map(str, [software_version1, software_version2, software_version3])
+        )
         self._data = {DATA_VERSION: version_info}
 
 
@@ -196,7 +199,7 @@ class MixerParameters(Response):
         self._data, _ = mixer_parameters.from_bytes(message)
 
 
-REGDATA_SCHEMA: Mapping[int, str] = {
+REGDATA_SCHEMA: Dict[int, str] = {
     1792: DATA_MODE,
     1024: HEATING_TEMP,
     1026: FEEDER_TEMP,
@@ -225,7 +228,7 @@ class DataSchema(Response):
         offset = 0
         blocks_number = util.unpack_ushort(message[offset : offset + 2])
         offset += 2
-        schema: MutableSequence[Tuple[str, DataType]] = []
+        schema: List[Tuple[str, DataType]] = []
         if blocks_number > 0:
             for _ in range(blocks_number):
                 param_type = message[offset]
